@@ -44,10 +44,18 @@ KBlocksWin::KBlocksWin(KBlocksGameLogic *p, KBlocksPlayManager *pM, int capacity
     mMaxGameCapacity = capacity;
     mGameCount = gamecount;
     mpGameLogic = p;
+    connect(mpGameLogic, &KBlocksGameLogic::allGamesStopped,
+            this, &KBlocksWin::onAllGamesStopped);
+
     mpPlayManager = pM;
 
     mpGameScene = new KBlocksScene(mpGameLogic, capacity);
 
+    connect(mpKBPlayer, &KBlocksKeyboardPlayer::blockMoved,
+            mpGameScene, &KBlocksScene::playMoveSound);
+    connect(mpKBPlayer, &KBlocksKeyboardPlayer::blockDropped,
+            mpGameScene, &KBlocksScene::playDropSound);
+
     mpGameView = new KBlocksView(mpGameScene, this);
     mpGameView->show();
     setCentralWidget(mpGameView);
@@ -121,17 +129,17 @@ void KBlocksWin::startGame()
     }
 
     mScore->setText(i18n("Points: %1 - Lines: %2 - Level: %3", 0, 0, 0));
+
+    m_pauseAction->setEnabled(true);
+    m_pauseAction->setChecked(false);
 }
 
 void KBlocksWin::stopGame()
 {
-    if (mpGameLogic->stopGame()) {
-        mpPlayManager->stopGame();
-
+    if (mpGameLogic->deleteSingleGames()) {
+        // Clear the game field
         mpGameScene->stopGame();
         mpGameScene->deleteGameItemGroups();
-
-        Kg::difficulty()->setGameRunning(false);
     }
 }
 
@@ -144,6 +152,13 @@ void KBlocksWin::pauseGame()
     Kg::difficulty()->setGameRunning(!m_pauseAction->isChecked());
 }
 
+void KBlocksWin::onAllGamesStopped()
+{
+    mpPlayManager->stopGame();
+    m_pauseAction->setEnabled(false);
+    Kg::difficulty()->setGameRunning(false);
+}
+
 void KBlocksWin::singleGame()
 {
     mpPlayManager->stopGame();
@@ -260,6 +275,7 @@ void KBlocksWin::setupGUILayout()
 
     m_pauseAction = KStandardGameAction::pause(this, SLOT(pauseGame()), actionCollection());
     actionCollection()->addAction(QStringLiteral("pauseGame"), m_pauseAction);
+    m_pauseAction->setEnabled(false);
 
     action = KStandardGameAction::highscores(this, SLOT(showHighscore()), actionCollection());
     actionCollection()->addAction(QStringLiteral("showHighscores"), action);
